///////////////////////////////////////////////////
///////////////////////////////////////////////////
//EasyMenu Menu Creation System//////Version 1.22//
////////////////created by comfox//////////////////
///////copyright Finalis Software 2006 (c)/////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////

/////////////////////INTRO/////////////////////////

//Welcome to EasyMenu Menu Creation System!  This program
//allows the intuitive and graphical creation of menus for
//rpgtoolkit games, without requiring any coding at all.
//See the readme for details about EasyMenu's features
//and how to use them.

//Version 1.22 Notes:

//Special Note:  The in-menu refreshing of variables is not
//yet available due to inefficiencies in the toolkit itself,
//and as soon as a way around this is discovered, the feature
//will be implemented.  For now, the refresh variable option
//in Menu Settings has been locked to prevent incompatability
//of saved files with future versions.  All other features,
//including non-refreshing variables, are functional.

//New Features:
//  Copy Cell
//  Move Cell
//  "Render" now both initiates and closes Render Mode, and
//       the "Draw" button has been removed
//  Editing Coordinates by Keyboard is done with a better
//       selection system that is easy to use even with
//       full-screen cells
//  All cells now display all pertinent information in Draw
//       Mode



//Bugs Fixed:
//  Minor Efficiency Problems
//  Mouse Selection Bug
//  Layer Display for layers input over the maximum or
//       under the mininum layer number


//All older saved files are compatible with 1.22.

//Version 1.23 Release Date:  Undecided


///////////////////Variables///////////////////////

//You may, if you wish, modify the following variables from
//their default values.  The dimensions of the Action Menu
//are modifiable from within the program, but the rest are not
//in this version.  Note:  Width and height values should be given
//as numbers between 1 and 100, representing percentages of the
//screen, unless otherwise indicated.  This is to ensure compatability
//with all resolutions.  Decimals are acceptable, of course, as are
//fractions.

actionmenuwidth!=15  //the width of the action menu
actionmenuheight!=78  //the height of the action menu
editmenuwidth!=15  //the width of the edit menu
editmenuheight!=65  //the height of the edit menu
max_layer!=10  //the highest image layer you'll use
moveint!=5  //the number of pixels a cell moves by each key press in "Move Cell"
sr!=255 //the red value of the colorrgb of noteworthy cells
sg!=128 //the green value of the colorrgb of noteworthy cells
sb!=192 //the blue value of the colorrgb of noteworthy cells
hr!=255 //the red value of the colorrgb of highlighted cells
hg!=255 //the green value of the colorrgb of highlighted cells
hb!=0 //the blue value of the colorrgb of highlighted cells

///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
////////////BEGINNING OF CODE//////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////
///////////////////////////////////////////////////

//These variables are part of the program and not to be edited
//by the user:
setting[refresh]$="No"
setting[refresh_rate]!=0
number_of_cells!=0
number_of_buttons_in_actionmenu!=12
number_of_buttons["edit"]!=10
am_button_identity[0]$="Create Cell"
am_button_identity[1]$="Copy Cell"
am_button_identity[2]$="Move Cell"
am_button_identity[3]$="Edit Cell"
am_button_identity[4]$="Delete Cell"
am_button_identity[5]$="Modify Action Menu"
am_button_identity[6]$="Render"
am_button_identity[7]$="Menu Settings"
am_button_identity[8]$="Load"
am_button_identity[9]$="Save"
am_button_identity[10]$="Exit"
button_identity["edit"][0]$="Align With Other Cell"
button_identity["edit"][1]$="Modify Coordinates With Mouse"
button_identity["edit"][2]$="Modify Coordinates With Keyboard"
button_identity["edit"][3]$="Modify Image"
button_identity["edit"][4]$="Modify Text"
button_identity["edit"][5]$="Modify Variable"
button_identity["edit"][6]$="Modify Translucency"
button_identity["edit"][7]$="Modify Layer"
button_identity["edit"][8]$="Modify Type"
button_identity["edit"][9]$="Modify Button Link"
typechoose[1]$="image"
typechoose[2]$="button"
typechoose[3]$="text"
typechoose[4]$="static_var"
typechoose[5]$="image_var"
typemax!=5
font!=getfontsize()
GetRes(resx!,resy!)
//end variable block




Method PtP(ptpwidth!,ptpheight!)  //Percent to Pixel
{
	GetRes(resx!,resy!)
	pwidth!=resx!*ptpwidth!/100
	pheight!=resy!*ptpheight!/100
}

Method ActionMenu(clickx!,clicky!,actionmenuwidth!,actionmenuheight!)
{
	PtP(actionmenuwidth!,actionmenuheight!)
	pheight!=pheight!/number_of_buttons_in_actionmenu!
	for (num! = 0; num! < number_of_buttons_in_actionmenu!; num!++)
	{
		num$ = CastLit(num!)
		file$="button"+num$+".jpg"
		add!=num!*pheight!
		locy!=clicky!+add!
		SetButton(file$,num!,clickx!,locy!,pwidth!,pheight!)
	}
	Kill(num$)
	Kill(file$)
	Kill(add!)
	Kill(locy!)
	MouseClick(clickx!,clicky!)
	buttonnum!=CheckButton(clickx!,clicky!)
	ClearButtons()
	DrawAllCells()
	If(buttonnum! < number_of_buttons_in_actionmenu!)
	{
		If(buttonnum! >= 0)
		{
			Button(buttonnum!)
		}
	}
}

Method Menu(name$,clickx!,clicky!,menuwidth!,menuheight!)
{
	Ptp(menuwidth!,menuheight!)
	pheight!=pheight!/number_of_buttons[name$]!
	for (num! = 0; num! < number_of_buttons[name$]!; num!++)
	{
		num$=castlit(num!)
		file$=name$+"button"+num$+".jpg"
		add!=num!*pheight!
		SetButton(file$,num!,clickx!,clicky!+add!,pwidth!,pheight!)
	}
	Kill(file$)
	Kill(add!)
	Kill(num$)
	MouseClick(clickx!,clicky!)
	buttonnum!=CheckButton(clickx!,clicky!)
	ClearButtons()
	If(buttonnum! < number_of_buttons[name$]!)
	{
		If(buttonnum!>=0)
		{
			Button(buttonnum!,name$)
		}
	}
}


Method CreateCell(x1!,y1!,x2!,y2!,layer!,type$,image_filename$)
{
	cell[number_of_cells!][layer]!=layer!
	If(layer! > max_layer!)
	{
		cell[number_of_cells!][layer]!=max_layer!
		layer! = max_layer!
	}
	ElseIf(layer! < 0)
	{
		cell[number_of_cells!][layer]!=0
		layer! = 0
	}
	num$=CastLit(number_of_cells!)
	layer$=CastLit(layer!)
	cell[number_of_cells!][type]$=type$
	cell[number_of_cells!][texty]!=(y1!+y2!)/2
	cell[number_of_cells!][text]$=num$+"; "+type$+"; "+"layer "+layer$
	cell[number_of_cells!][image]$=image_filename$
	cell[cellnum!][translucent]!=0
	If(x2! >= x1!)
	{
		cell[number_of_cells!][width]!=x2!-x1!
		cell[number_of_cells!][x1]!=x1!
		cell[number_of_cells!][x2]!=x2!
		cell[number_of_cells!][textx]!=x1!
	}
	Else
	{
		cell[number_of_cells!][width]!=x1!-x2!
		cell[number_of_cells!][x1]!=x2!
		cell[number_of_cells!][x2]!=x1!
		cell[number_of_cells!][textx]!=x2!
	}
	If(y2! >= y1!)
	{
		cell[number_of_cells!][height]!=y2!-y1!
		cell[number_of_cells!][y1]!=y1!
		cell[number_of_cells!][y2]!=y2!
	}
	Else
	{
		cell[number_of_cells!][height]!=y1!-y2!
		cell[number_of_cells!][y1]!=y2!
		cell[number_of_cells!][y2]!=y1!
	}
	number_of_cells!=number_of_cells!+1
	Kill(num$)
	Kill(layer$)
}

Method DrawCell(cellnum!)
{
	DrawRect(cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][x2]!,cell[cellnum!][y2]!)
	PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,cell[cellnum!][text]$)
	Switch(cell[cellnum!][type]$)
	{
		case("button") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image]$)
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!+font!,cell[cellnum!][link]$)
		}
		case("text") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][display_text]$)
		}
		case("static_var") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][static_var_complete]$)
		}
		case("image_var") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image_var]$)
		}
		case("image") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image]$)
		}
	}
}

Method DrawCell(cellnum!,canvas!)
{
	DrawRect(cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][x2]!,cell[cellnum!][y2]!,canvas!)
	PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,cell[cellnum!][text]$,canvas!)
	Switch(cell[cellnum!][type]$)
	{
		case("button") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image]$,canvas!)
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!+font!,cell[cellnum!][link]$,canvas!)
		}
		case("text") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][display_text]$,canvas!)
		}
		case("static_var") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][static_var_complete]$,canvas!)
		}
		case("image_var") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image_var]$,canvas!)
		}
		case("image") {
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!+font!,cell[cellnum!][image]$,canvas!)
		}
	}
}

Method RenderCell(cellnum!)
{
	switch(cell[cellnum!][type]$)
	{
		case("static_var") {
			osize!=getfontsize()
			fontsize(cell[cellnum!][fontsize]!)
			Switch(cell[cellnum!][static_var_type]$)
			{
				case("numeric") {
					rpgcode("valueoo$=castlit("+cell[cellnum!][static_var_complete]$+")")
				}
				case("literal") {
					rpgcode("valueoo$="+cell[cellnum!][static_var_complete]$)
				}
			}
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,valueoo$)
			kill(valueoo$)
			fontsize(osize!)
			kill(osize!)
		}
		case("text") {
			osize!=getfontsize()
			fontsize(cell[cellnum!][fontsize]!)
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,cell[cellnum!][display_text]$)
			fontsize(osize!)
			kill(osize!)
		}
		case("image_var") {
			If(cell[cellnum!][translucent]!==1)
			{
				rpgcode("SetImageTranslucent("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!)")
			}
			ElseIf(cell[cellnum!][translucent]!==2)
			{
				rpgcode("SetImageTransparent("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,cell[cellnum!][tr]!,cell[cellnum!][tg]!,cell[cellnum!][tb]!)")
			}
			Else
			{
				rpgcode("SetImage("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!)")
			}
		}
		case(Else) {
			If(cell[cellnum!][translucent]!==1)
			{
				SetImageTranslucent(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!)
			}
			ElseIf(cell[cellnum!][translucent]!==2)
			{
				SetImageTransparent(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,cell[cellnum!][tr]!,cell[cellnum!][tg]!,cell[cellnum!][tb]!)
			}
			Else
			{
				SetImage(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!)
			}
		}
	}
}


Method RenderCell(cellnum!,canvas!)
{
	switch(cell[cellnum!][type]$)
	{
		case("static_var") {
			osize!=getfontsize()
			fontsize(cell[cellnum!][fontsize]!)
			Switch(cell[cellnum!][static_var_type]$)
			{
				case("numeric") {
					rpgcode("valueoo$=castlit("+cell[cellnum!][static_var_complete]$+")")
				}
				case("literal") {
					rpgcode("valueoo$="+cell[cellnum!][static_var_complete]$)
				}
			}
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,valueoo$,canvas!)
			kill(valueoo$)
			fontsize(osize!)
			kill(osize!)
		}
		case("text") {
			osize!=getfontsize()
			fontsize(cell[cellnum!][fontsize]!)
			PixelText(cell[cellnum!][textx]!,cell[cellnum!][texty]!,cell[cellnum!][display_text]$,canvas!)
			fontsize(osize!)
			kill(osize!)
		}
		case("image_var") {
			If(cell[cellnum!][translucent]!==1)
			{
				rpgcode("SetImageTranslucent("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,canvas!)")
			}
			ElseIf(cell[cellnum!][translucent]!==2)
			{
				rpgcode("SetImageTransparent("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,cell[cellnum!][tr]!,cell[cellnum!][tg]!,cell[cellnum!][tb]!,canvas!)")
			}
			Else
			{
				rpgcode("SetImage("+cell[cellnum!][image_var]$+"$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,canvas!)")
			}
		}
		case(Else) {
			If(cell[cellnum!][translucent]!==1)
			{
				SetImageTranslucent(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,canvas!)
			}
			ElseIf(cell[cellnum!][translucent]!==2)
			{
				SetImageTransparent(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,cell[cellnum!][tr]!,cell[cellnum!][tg]!,cell[cellnum!][tb]!,canvas!)
			}
			Else
			{
				SetImage(cell[cellnum!][image]$,cell[cellnum!][x1]!,cell[cellnum!][y1]!,cell[cellnum!][width]!,cell[cellnum!][height]!,canvas!)
			}
		}
	}
}

Method DrawAllCells()
{
	drawallcells! = createCanvas(resx!,resy!)
	for(num! = 0; num! < number_of_cells!; num!++)
	{
		DrawCell(num!,drawallcells!)
	}
	kill(num!)
	DrawCanvas(drawallcells!,0,0)
	KillCanvas(drawallcells!)
	If(number_of_cells! == 0)
	{
	pixeltext(resx!/2.3,0,"EasyMenu 1.22")
	pixeltext(resx!/2.3,getfontsize(),"Click for Menu")
	}
}

Method RenderAllCells()
{
	getres(resx!,resy!)
	drawallcells! = createCanvas(resx!,resy!)
	for(layernum! = 0; layernum! <= max_layer!; layernum!++)
	{
		for(num! = 0; num! < number_of_cells!; num!++)
		{
			If(cell[num!][layer]!==layernum!)
			{
				RenderCell(num!,drawallcells!)
			}
		}
	}
	kill(num!)
	kill(layernum!)
	DrawCanvas(drawallcells!,0,0)
	KillCanvas(drawallcells!)
}


Method EditCell(cellnum!)
{
	ColorRGB(hr!,hg!,hb!)
	DrawCell(cellnum!)
	Menu("edit",0,0,editmenuwidth!,editmenuheight!)
	ColorRGB(r!,g!,b!)
}


Method Button(buttonnum!)
{
	Switch(am_button_identity[buttonnum!]$)
	{
		case("Create Cell") {
			MouseClick(x1!,y1!)
			SetPixel(x1!,y1!)
			MouseClick(x2!,y2!)
			DrawRect(x1!,y1!,x2!,y2!)
			Prompt("On what layer is this cell?",layer$)
			layer!=castnum(layer$)
			
			donn!=0
			t!=1
			while(donn!=0)
			{
				Clear()
				DrawRect(x1!,y1!,x2!,y2!)
				pixeltext(0,0,"Arrow Keys--Choose Type;  Enter--Select")
				Switch(typechoose[t!]$)
				{
					case("static_var") {
						pixeltext(0,getfontsize(),"Type: variable")
					}
					case("image_var") {
						pixeltext(0,getfontsize(),"Type: variable-defined image")
					}
					case(Else) {
						pixeltext(0,getfontsize(),"Type: "+typechoose[t!]$)
					}
				}
				chewbacca$=Wait()
				Switch(chewbacca$)
				{
					case("ENTER") {
						donn!=1
						type$=typechoose[t!]$
					}
					case("RIGHT") {
						t!=t!+1
					}
					case("LEFT") {
						t!=t!-1
					}
					case("UP") {
						t!=t!+1
					}
					case("DOWN") {
						t!=t!-1
					}
				}
				If(t! > typemax!)
				{
					t!=1
				}
				If(t! == 0)
				{
					t!=typemax!
				}
			}
			Switch(type$)
			{
				case("button") {
					Prompt("What .prg should the button link to?",cell[number_of_cells!][link]$)
					Prompt("What image should be set to the button?",image_filename$)
				}
				case("text") {
					Prompt("What text should be displayed?",cell[number_of_cells!][display_text]$)
					cell[number_of_cells!][fontsize]!=12
					image_filename$="nonexistent_image.jpg"
				}
				case("static_var") {
					Prompt("What variable should be displayed--leave off numeric/literal indicator?",cell[number_of_cells!][static_var_handle]$)
					Prompt("Is the variable numeric or literal?",cell[number_of_cells!][static_var_type]$)
					cell[number_of_cells!][static_var_complete]$=SetStringType(cell[number_of_cells!][static_var_handle]$,cell[number_of_cells!][static_var_type]$)
					cell[number_of_cells!][fontsize]!=12
					image_filename$="nonexistent_image.jpg"
				}
				case("image_var") {
					Prompt("What variable contains the image filename?  Leave off the literal indicator.",cell[number_of_cells!][image_var]$)
					image_filename$="nonexistent_image.jpg"
				}
				case(Else) {
					type$="image"
					Prompt("What image should be set to this cell?",image_filename$)
				}
			}
			CreateCell(x1!,y1!,x2!,y2!,layer!,type$,image_filename$)
			kill(x1!)
			kill(y1!)
			kill(x2!)
			kill(y2!)
			kill(layer$)
			kill(layer!)
			kill(type$)
			kill(image_filename$)
			DrawAllCells()
		}
		case("Copy Cell") {
			Mwin("Select a cell to copy.")
			kill(x!)
			kill(y!)
			kill(sel!)
			MouseClick(x!,y!)
			MWinCls()
			CheckCell(x!,y!)
			Cycle()
			kill(cellnum!)
			cellnum!=sel!
			kill(sel!)
			ColorRGB(hr!,hg!,hb!)
			DrawCell(cellnum!)
			ColorRGB(r!,g!,b!)
			Mwin("Click to place copy.")
			MouseClick(x!,y!)
			MWinCls()
			Switch(cell[cellnum!][type]$)
			{
				case("button") {
					cell[number_of_cells!][link]$ = cell[cellnum!][link]$
				}
				case("text") {
					cell[number_of_cells!][display_text]$ = cell[cellnum!][display_text]$
					cell[number_of_cells!][fontsize]! = cell[cellnum!][fontsize]!
				}
				case("static_var") {
					cell[number_of_cells!][static_var_handle]$ = cell[cellnum!][static_var_handle]$
					cell[number_of_cells!][static_var_type]$ = cell[cellnum!][static_var_type]$
					cell[number_of_cells!][static_var_complete]$=SetStringType(cell[number_of_cells!][static_var_handle]$,cell[number_of_cells!][static_var_type]$)
					cell[number_of_cells!][fontsize]!=12
				}
				case("image_var") {
					cell[number_of_cells!][image_var]$ = cell[cellnum!][image_var]$
				}
			}
			CreateCell(x!,y!,x! + cell[cellnum!][width]!,y! + cell[cellnum!][height]!,cell[cellnum!][layer]!,cell[cellnum!][type]$,cell[cellnum!][image]$)
			kill(x!)
			kill(y!)
			kill(cellnum!)
			DrawAllCells()
		}
		case("Move Cell") {
			MWin("Select a cell to move.")
			MouseClick(x!,y!)
			MWinCls()
			CheckCell(x!,y!)
			Cycle()
			cellnum!=sel!
			ColorRGB(hr!,hg!,hb!)
			DrawCell(cellnum!)
			ColorRGB(r!,g!,b!)
			kill(sel!)
			MWin("Click to reposition cell.  Click within the selected cell to move it with the keyboard.")
			MouseClick(x!,y!)
			MWinCls()
			If(x! > cell[cellnum!][x1]!)
			{
				If(x! < cell[cellnum!][x2]!)
				{
					If(y! < cell[cellnum!][y2]!)
					{
						If(y! > cell[cellnum!][y1]!)
						{
							used_keys_to_move! = 1
							movewhile! = 0
							while(movewhile! = 0)
							{
								DrawAllCells()
								colorrgb(hr!,hg!,hb!)
								DrawCell(cellnum!)
								colorrgb(r!,g!,b!)
								pixeltext(0,0,"Arrow Keys--Move; l,r,u,d--Move by One Pixel;  Enter--Done")
								pressed$ = Wait()
								Switch(pressed$)
								{
									case("ENTER") {
										movewhile! = 1
									}
									case("UP") {
										If(cell[cellnum!][y1]! > 0)
										{
											cell[cellnum!][y1]! = cell[cellnum!][y1]! - moveint!
											cell[cellnum!][y2]! = cell[cellnum!][y2]! - moveint!
											cell[cellnum!][texty]! = cell[cellnum!][texty]! - moveint!
										}
									}
									case("DOWN") {
										If(cell[cellnum!][y2]! < resy!)
										{
											cell[cellnum!][y1]! = cell[cellnum!][y1]! + moveint!
											cell[cellnum!][y2]! = cell[cellnum!][y2]! + moveint!
											cell[cellnum!][texty]! = cell[cellnum!][texty]! + moveint!
										}
									}
									case("LEFT") {
										If(cell[cellnum!][x1]! > 0)
										{
											cell[cellnum!][x1]! = cell[cellnum!][x1]! - moveint!
											cell[cellnum!][x2]! = cell[cellnum!][x2]! - moveint!
											cell[cellnum!][textx]! = cell[cellnum!][textx]! - moveint!
										}
									}
									case("RIGHT") {
										If(cell[cellnum!][x2]! < resx!)
										{
											cell[cellnum!][x1]! = cell[cellnum!][x1]! + moveint!
											cell[cellnum!][x2]! = cell[cellnum!][x2]! + moveint!
											cell[cellnum!][textx]! = cell[cellnum!][textx]! + moveint!
										}
									}
									case("U") {
										If(cell[cellnum!][y1]! > 0)
										{
											cell[cellnum!][y1]! = cell[cellnum!][y1]! - 1
											cell[cellnum!][y2]! = cell[cellnum!][y2]! - 1
											cell[cellnum!][texty]! = cell[cellnum!][texty]! - 1
										}
									}
									case("D") {
										If(cell[cellnum!][y2]! < resy!)
										{
											cell[cellnum!][y1]! = cell[cellnum!][y1]! + 1
											cell[cellnum!][y2]! = cell[cellnum!][y2]! + 1
											cell[cellnum!][texty]! = cell[cellnum!][texty]! + 1
										}
									}
									case("L") {
										If(cell[cellnum!][x1]! > 0)
										{
											cell[cellnum!][x1]! = cell[cellnum!][x1]! - 1
											cell[cellnum!][x2]! = cell[cellnum!][x2]! - 1
											cell[cellnum!][textx]! = cell[cellnum!][textx]! - 1
										}
									}
									case("R") {
										If(cell[cellnum!][x2]! < resx!)
										{
											cell[cellnum!][x1]! = cell[cellnum!][x1]! + 1
											cell[cellnum!][x2]! = cell[cellnum!][x2]! + 1
											cell[cellnum!][textx]! = cell[cellnum!][textx]! + 1
										}

									}
								}
							}
							kill(pressed$)
							kill(movewhile!)
						}
					}
				}
			}
			If(used_keys_to_move! == 0)
			{
				cell[cellnum!][x1]! = x!
				cell[cellnum!][x2]! = x! + cell[cellnum!][width]!
				cell[cellnum!][y1]! = y!
				cell[cellnum!][y2]! = y! + cell[cellnum!][height]!
				cell[cellnum!][textx]! = x!
				cell[cellnum!][texty]! = (cell[cellnum!][y1]! + cell[cellnum!][y2]!) / 2
			}
			kill(used_keys_to_move!)
			kill(x!)
			kill(y!)
			kill(cellnum!)
			DrawAllCells()
		}
		case("Edit Cell") {
			Mwin("Select a cell to edit.")
			MouseClick(x!,y!)
			MWinCls()
			CheckCell(x!,y!)
			Cycle()
			cellnum!=sel!
			EditCell(cellnum!)
			DrawAllCells()
			kill(sel!)
		}
		case("Delete Cell") {
			Mwin("Select a cell.")
			MouseClick(x!,y!)
			MWinCls()
			CheckCell(x!,y!)
			Cycle()
			cellnum!=sel!
			kill(cell[cellnum!][link]$)
			kill(cell[cellnum!][translucent]!)
			truenum!=number_of_cells!-1
			number_of_cells!=cellnum!
			CreateCell(cell[truenum!][x1]!,cell[truenum!][y1]!,cell[truenum!][x2]!,cell[truenum!][y2]!,cell[truenum!][layer]!,cell[truenum!][type]$,cell[truenum!][image]$)
			number_of_cells!=truenum!
			kill(truenum!)
			kill(cellnum!)
			DrawAllCells()
		}
		case("Modify Action Menu") {
			incr!=3
			size!=getFontSize()
			actionmenuwidth!=resx!*actionmenuwidth!/100
			actionmenuheight!=resy!*actionmenuheight!/100
			while(amdone!==0)
			{
				drawallcells! = createCanvas(resx!,resy!)
				for(num! = 0; num! < number_of_cells!; num!++)
				{
					DrawCell(num!,drawallcells!)
				}
				kill(num!)
				DrawRect(resx!/2,0,resx!/2+actionmenuwidth!,actionmenuheight!,drawallcells!)
				pixeltext(0,0,"Arrow Keys--Adjust Size",drawallcells!)
				pixeltext(0,size!,"Enter--Adjustment Complete",drawallcells!)
				DrawCanvas(drawallcells!,0,0)
				KillCanvas(drawallcells!)
				pressed$=Wait()
				Switch(pressed$)
				{
					case("RIGHT")
					{
						actionmenuwidth!=actionmenuwidth!+incr!
					}
					case("LEFT")
					{
						actionmenuwidth!=actionmenuwidth!-incr!
					}
					case("UP")
					{
						actionmenuheight!=actionmenuheight!-incr!
					}
					case("DOWN")
					{
						actionmenuheight!=actionmenuheight!+incr!
					}
					case("ENTER")
					{
						amdone!=1
					}
				}
			}
			kill(amdone!)
			kill(pressed$)
			kill(incr!)
			kill(size!)
			actionmenuwidth!=actionmenuwidth!*100/resx!
			actionmenuheight!=actionmenuheight!*100/resy!
			DrawAllCells()
		}
		case("Render") {
			If(rendered! == 1)
			{
			DrawAllCells()
			kus! = 1
			rendered! = 0
			}
			If(kus! == 0)
			{
			RenderAllCells()
			rendered! = 1
			kus! = 0
			}
			kus! = 0
		}
		case("Menu Settings") {
			While(setting_edit_done!=0)
			{
				Clear()
				PixelText(0,0,"A: Refresh for Variable Update:  <setting[refresh]$>")
				PixelText(0,getfontsize(),"B: Refresh rate:  "+castlit(setting[refresh_rate]!))
				PixelText(0,2*getfontsize(),"ENTER: Changes Complete.")
				PixelText(resx!/3,resy!/2,"What would you like to change?  Input by letter.")
				change$=Wait()
				Switch(change$)
				{
					case("A") {
						Mwin("               Feature not yet available.")
						Wait()
						MwinCls()
					}
					case("B") {
						Mwin("               Feature not yet available.")
						Wait()
						MwinCls()
					}
					case("ENTER") {
						setting_edit_done!=1
					}
				}
			}
			DrawAllCells()
			setting_edit_done!=0
		}
		case("Save") {
			Prompt("Where should the file be saved?",toopen$)
			SaveMenu(toopen$)
		}
		case("Load") {
			Prompt("What file should be loaded?",toopen$)
			LoadMenu(toopen$)
		}
		case("Exit") {
			end!=1
		}
	}
}







Method Button(buttonnum!,name$)
{
	If(name$=="edit")
	{
		Switch(button_identity["edit"][buttonnum!]$)
		{
			case("Align With Other Cell") {
				ClearButtons()
				Clear()
				colorrgb(r!,g!,b!)
				DrawAllCells()
				colorrgb(hr!,hg!,hb!)
				DrawCell(cellnum!)
				Mwin("Select the cell to align with.")
				MouseClick(x!,y!)
				MWinCls()
				CheckCell(x!,y!)
				Cycle()
				cell2!=sel!
				colorrgb(hr!,hg!,hb!)
				pixeltext(cell[cellnum!][x1]!,cell[cellnum!][y1]!,"x1,y1")
				pixeltext(cell[cellnum!][x1]!,cell[cellnum!][y2]!,"x1,y2")
				pixeltext(cell[cellnum!][x2]!,cell[cellnum!][y1]!,"x2,y1")
				pixeltext(cell[cellnum!][x2]!,cell[cellnum!][y2]!,"x2,y2")
				colorrgb(sr!,sg!,sb!)
				DrawCell(cell2!)
				pixeltext(cell[cell2!][x1]!,cell[cell2!][y1]!,"x1,y1")
				pixeltext(cell[cell2!][x1]!,cell[cell2!][y2]!,"x1,y2")
				pixeltext(cell[cell2!][x2]!,cell[cell2!][y1]!,"x2,y1")
				pixeltext(cell[cell2!][x2]!,cell[cell2!][y2]!,"x2,y2")
				colorrgb(r!,g!,b!)
				Prompt("Which coordinate would you like to change? x1, y1, x2, or y2?",coord$)
				Switch(coord$)
				{
					case("x1") {
						Prompt("Match other cell's x1 or x2?",xn$)
						truenum!=number_of_cells!
						number_of_cells!=cellnum!
						CreateCell(cell[cell2!][xn$]!,cell[number_of_cells!][y1]!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
						number_of_cells!=truenum!
					}
					case("x2") {
						Prompt("Match other cell's x1 or x2?",xn$)
						truenum!=number_of_cells!
						number_of_cells!=cellnum!
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,cell[cell2!][xn$]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
						number_of_cells!=truenum!
					}
					case("y1") {
						Prompt("Match other cell's y1 or y2?",yn$)
						truenum!=number_of_cells!
						number_of_cells!=cellnum!
						CreateCell(cell[number_of_cells!][x1]!,cell[cell2!][yn$]!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
						number_of_cells!=truenum!
					}
					case("y2") {
						Prompt("Match other cell's y1 or y2?",yn$)
						truenum!=number_of_cells!
						number_of_cells!=cellnum!
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,cell[number_of_cells!][x2]!,cell[cell2!][yn$]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
						number_of_cells!=truenum!
					}
				}
				kill(coord$)
				kill(cell2!)
				kill(truenum!)
			}
			case("Modify Coordinates With Mouse") {
				ClearButtons()
				Clear()
				DrawAllCells()
				colorrgb(hr!,hg!,hb!)
				pixeltext(cell[cellnum!][x1]!,cell[cellnum!][y1]!,"A")
				pixeltext(cell[cellnum!][x2]!,cell[cellnum!][y2]!,"B")
				colorrgb(r!,g!,b!)
				Prompt("Which point would you like to change?",point$)
				Mwin("Click to reset point.")
				MouseClick(clickx!,clicky!)
				MwinCls()
				truenum!=number_of_cells!
				number_of_cells!=cellnum!
				Switch(point$)
				{
					case("A") {
						CreateCell(clickx!,clicky!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case("B") {
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,clickx!,clicky!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case("a") {
						CreateCell(clickx!,clicky!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case("b") {
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,clickx!,clicky!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
				}
				number_of_cells!=truenum!
				kill(point$)
				kill(truenum!)
			}
			case("Modify Coordinates With Keyboard") {
				ClearButtons()
				Clear()
				DrawAllCells()
				colorrgb(sr!,sg!,sb!)
				pixeltext(cell[cellnum!][x1]!,cell[cellnum!][y1]!+cell[cellnum!][height]!/2,"x1")
				pixeltext(cell[cellnum!][x2]!-getfontsize(),cell[cellnum!][y1]!+cell[cellnum!][height]!/2,"x2")
				pixeltext(cell[cellnum!][x1]!+cell[cellnum!][width]!/2,cell[cellnum!][y1]!,"y1")
				pixeltext(cell[cellnum!][x1]!+cell[cellnum!][width]!/2,cell[cellnum!][y2]!-getfontsize(),"y2")
				colorrgb(r!,g!,b!)
				MWin("Choose either x1, y1, x2, or y2.")
				MouseClick(x!,y!)
				MWinCls()
				xglomp! = (cell[cellnum!][x1]! + cell[cellnum!][width]!/2 - x!)^2
				yglomp! = (cell[cellnum!][y1]! + cell[cellnum!][height]!/2 - y!)^2
				y1dist! = (cell[cellnum!][y1]! - y!)^2
				y1dist! = y1dist! + xglomp!
				y2dist! = (cell[cellnum!][y2]! - y!)^2
				y2dist! = y2dist! + xglomp!
				x1dist! = (cell[cellnum!][x1]! - x!)^2
				x1dist! = x1dist! + yglomp!
				x2dist! = (cell[cellnum!][x2]! - x!)^2
				x2dist! = x2dist! + yglomp!
				If(x1dist! <= x2dist!)
				{
					If(x1dist! <= y1dist!)
					{
						If(x1dist! <= y2dist!)
						{
							sel!=1
						}
					}
				}
				If(x2dist! <= x1dist!)
				{
					If(x2dist! <= y1dist!)
					{
						If(x2dist! <= y2dist!)
						{
							sel!=2
						}
					}
				}
				If(y1dist! <= y2dist!)
				{
					If(y1dist! <= x1dist!)
					{
						If(y1dist! <= x2dist!)
						{
							sel!=3
						}
					}
				}
				If(y2dist! <= y1dist!)
				{
					If(y2dist! <= x1dist!)
					{
						If(y2dist! <= x2dist!)
						{
							sel!=4
						}
					}
				}
				kill(xglomp!)
				kill(yglomp!)
				kill(x1dist!)
				kill(y1dist!)
				kill(x2dist!)
				kill(y2dist!)
				DrawAllCells()
				colorrgb(hr!,hg!,hb!)
				Switch(sel!)
				{
					case(1) {
						pixeltext(cell[cellnum!][x1]!,cell[cellnum!][y1]!+cell[cellnum!][height]!/2,"x1: " + castlit(cell[cellnum!][x1]!))
					}
					case(2) {
						pixeltext(cell[cellnum!][x2]!-getfontsize(),cell[cellnum!][y1]!+cell[cellnum!][height]!/2,"x2: " + castlit(cell[cellnum!][x2]!))
					}
					case(3) {
						pixeltext(cell[cellnum!][x1]!+cell[cellnum!][width]!/2,cell[cellnum!][y1]!,"y1: " + castlit(cell[cellnum!][y1]!))
					}
					case(4) {
						pixeltext(cell[cellnum!][x1]!+cell[cellnum!][width]!/2,cell[cellnum!][y2]!-getfontsize(),"y2: " + castlit(cell[cellnum!][y2]!))
					}
				}
				colorrgb(r!,g!,b!)
				Prompt("To what should the value be set? (type res to match your resolution)",value$)
				value!=castnum(value$)
				If(value$=="res")
				{
					Switch(sel!)
					{
						case(1) {
							value!=resx!
						}
						case(2) {
							value!=resx!
						}
						case(3) {
							value!=resy!
						}
						case(4) {
							value!=resy!
						}
					}
				}
				kill(value$)
				truenum!=number_of_cells!
				number_of_cells!=cellnum!
				Switch(sel!)
				{
					case(1) {
						CreateCell(value!,cell[number_of_cells!][y1]!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case(2) {
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,value!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case(3) {
						CreateCell(cell[number_of_cells!][x1]!,value!,cell[number_of_cells!][x2]!,cell[number_of_cells!][y2]!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
					case(4) {
						CreateCell(cell[number_of_cells!][x1]!,cell[number_of_cells!][y1]!,cell[number_of_cells!][x2]!,value!,cell[number_of_cells!][layer]!,cell[number_of_cells!][type]$,cell[number_of_cells!][image]$)
					}
				}
				number_of_cells!=truenum!
				kill(value!)
				kill(truenum!)
				kill(sel!)
				kill(areanum!)
			}
			case("Modify Image") {
				ClearButtons()
				Clear()
				DrawAllCells()
				If(cell[cellnum!][type]$=="image_var")
				{
					Prompt("Input the variable that contains the image filename; leave off the literal indicator.",cell[cellnum!][image_var]$)
				}
				Else
				{
					Prompt("Input correct image filename.",cell[cellnum!][image]$)
				}
			}
			case("Modify Text") {
				ClearButtons()
				Clear()
				DrawAllCells()
				Prompt("To what should the text be changed?",text$)
				Prompt("What should the font be?",font$)
				TextSet(cellnum!,castnum(font$),text$)
				kill(font$)
				kill(text$)
			}
			case("Modify Variable") {
				ClearButtons()
				Clear()
				DrawAllCells()
				Prompt("What variable should be displayed--leave off numeric/literal indicator?",text$)
				Prompt("Is the variable literal or numeric?",cell[cellnum!][static_var_type]$)
				Prompt("What should the font be?",font$)
				VarSet(cellnum!,castnum(font$),text$)
				cell[cellnum!][static_var_complete]$=SetStringType(text$,cell[cellnum!][static_var_type]$)
				kill(font$)
				kill(text$)
			}
			case("Modify Translucency") {
				ClearButtons()
				Clear()
				DrawAllCells()
				Prompt("2=Edit Transparency, 1=Translucent, 0=Opaque",translucent$)
				If(translucent$=="2")
				{
					Prompt("What is the red value of the transparent color?",tr$)
					Prompt("What is the green value of the transparent color?",tg$)
					Prompt("What is the blue value of the transparent color?",tb$)
					cell[cellnum!][translucent]!=2
					cell[cellnum!][tr]!=castnum(tr$)
					cell[cellnum!][tg]!=castnum(tg$)
					cell[cellnum!][tb]!=castnum(tb$)
					kill(tr$)
					kill(tg$)
					kill(tb$)
				}
				Else
				{
					cell[cellnum!][translucent]!=castnum(translucent$)
				}
				kill(translucent$)
			}
			case("Modify Layer") {
				ClearButtons()
				Clear()
				DrawAllCells()
				Prompt("Layer number?",layer$)
				cell[cellnum!][layer]!=castnum(layer$)
				cell[cellnum!][text]$= castlit(cellnum!)+"; "+cell[cellnum!][type]$+"; "+"layer "+castlit(cell[cellnum!][layer]!)
				kill(layer$)
			}
			case("Modify Type") {
				ClearButtons()
				Clear()
				colorrgb(r!,g!,b!)
				typechoose[typenum!]$=cell[cellnum!][type]$
				while(doneloop!=0)
				{
					DrawAllCells()
					PixelText(0,0,"Arrow Keys--Choose Type;  Enter--Select")
					If(typechoose[typenum!]$==cell[cellnum!][type]$)
					{
						colorrgb(hr!,hg!,hb!)
					}
					Switch(typechoose[typenum!]$)
					{
						case("static_var") {
							PixelText(0,getfontsize(),"variable")
						}
						case("image_var") {
							PixelText(0,getfontsize(),"variable-defined image")
						}
						case(Else) {
							PixelText(0,getfontsize(),typechoose[typenum!]$)
						}
					}
					colorrgb(r!,g!,b!)
					pressed$=Wait()
					Switch(pressed$)
					{
						case("UP") {
							typenum!=typenum!+1
						}
						case("DOWN") {
							typenum!=typenum!-1
						}
						case("RIGHT") {
							typenum!=typenum!+1
						}
						case("LEFT") {
							typenum!=typenum!-1
						}
						case("ENTER") {
							doneloop!=1
						}
					}
					If(typenum! > typemax!)
					{
						typenum! = 1
					}
					If(typenum! == 0)
					{
						typenum! = typemax!)
					}
				}
				cell[cellnum!][type]$=typechoose[typenum!]$
				Switch(typechoose[typenum!]$)
				{
					case("image")
					{
						Prompt("What image should be set to the cell?",cell[cellnum!][image]$)
					}
					case("button")
					{
						Prompt("What image should be set to the cell?",cell[cellnum!][image]$)
						Prompt("To what program should the button link?",cell[cellnum!][link]$)
					}
					case("text")
					{
						Prompt("What text should be set to the cell?",cell[cellnum!][display_text]$)
						Prompt("What font should be set to the cell?",cell[cellnum!][font]!)
						
					}
					case("static_var")
					{
						Prompt("What variable, leaving off the numeric/literal indicator, should be set to the cell?",cell[cellnum!][static_var_handle]$)
						Prompt("Is the variable numeric or literal?",cell[cellnum!][static_var_type]$)
					}
				}
				kill(typenum!)
			}
			case("Modify Button Link") {
				ClearButtons()
				Clear()
				DrawAllCells()
				Prompt("What .prg should be linked to?",cell[cellnum!][link]$)
			}
		}
	}
	DrawAllCells()
}


Method SaveMenu(toopen$)
{
	openFileOutput(toopen$,"Prg")
	closefile(toopen$)
	openFileAppend(toopen$,"Prg")
	FilePrint(toopen$,"//"+toopen$)
	FilePrint(toopen$,"Include(easymenu_library.prg)")
	create$="CreateCell("
	close$=")"
	for(writing! = 0; writing! < number_of_cells!; writing!++)
	{
		data$=create$+castlit(cell[writing!][x1]!)+","+castlit(cell[writing!][y1]!)+","+castlit(cell[writing!][x2]!)+","+castlit(cell[writing!][y2]!)+","+castlit(cell[writing!][layer]!)+","+cell[writing!][type]$+","+cell[writing!][image]$+close$
		FilePrint(toopen$,data$)
		Switch(cell[writing!][type]$)
		{
			case("button") {
				data$="cell[" + castlit(writing!) + "][link]$=" + cell[writing!][link]$
				FilePrint(toopen$,data$)
			}
			case("text") {
				data$="cell[" + castlit(writing!) + "][display_text]$=" + cell[writing!][display_text]$
				FilePrint(toopen$,data$)
				data$="cell[" + castlit(writing!) + "][fontsize]!=" + castlit(cell[writing!][fontsize]!)
				FilePrint(toopen$,data$)
			}
			case("static_var") {
				data$="cell[" + castlit(writing!) + "][static_var_handle]$=" + cell[writing!][static_var_handle]$
				FilePrint(toopen$,data$)
				data$="cell[" + castlit(writing!) + "][static_var_type]$=" + cell[writing!][static_var_type]$
				FilePrint(toopen$,data$)
				data$="cell[" + castlit(writing!) + "][static_var_complete]$=SetStringType(cell[" + castlit(writing!) + "][static_var_handle]$, cell[" + castlit(writing!) + "][static_var_type]$)"
				FilePrint(toopen$,data$)
				data$="cell[" + castlit(writing!) + "][fontsize]!=" + castlit(cell[writing!][fontsize]!)
				FilePrint(toopen$,data$)
			}
			case("image_var") {
				data$="cell[" + castlit(writing!) + "][image_var]$=" + cell[writing!][image_var]$
				FilePrint(toopen$,data$)
			}
		}
		data$="cell[" + castlit(writing!) + "][translucent]!=" + castlit(cell[writing!][translucent]!)
		FilePrint(toopen$,data$)
		If(cell[writing!][translucent]!==2)
		{
			data$="cell[" + castlit(writing!) + "][tr]!=" + castlit(cell[writing!][tr]!)
			FilePrint(toopen$,data$)
			data$="cell[" + castlit(writing!) + "][tg]!=" + castlit(cell[writing!][tg]!)
			FilePrint(toopen$,data$)
			data$="cell[" + castlit(writing!) + "][tb]!=" + castlit(cell[writing!][tb]!)
			FilePrint(toopen$,data$)
		}
	}
	data$="number_of_cells!=" + castlit(number_of_cells!)
	FilePrint(toopen$,data$)
	data$="max_layer!=" + castlit(max_layer!)
	FilePrint(toopen$,data$)
	FilePrint(toopen$,"/////////////////////////////////")
	FilePrint(toopen$,"////////END OF VARIABLES/////////")
	FilePrint(toopen$,"/////////////////////////////////")
	FilePrint(toopen$,"GetRes(resx!,resy!)")
	FilePrint(toopen$,"RenderAllCells()")
	If(setting[refresh]$=="Yes")
	{
		FilePrint(toopen$,"refresh_thread!=thread(refresh_prog.prg,1)")
	}
	FilePrint(toopen$,"While(loopcomp!==0)")
	FilePrint(toopen$,"{")
		FilePrint(toopen$,"MouseClick(x!,y!)")
		FilePrint(toopen$,"button_pressed!=CheckButton(x!,y!)")
		FilePrint(toopen$,"If(button_pressed! ~= -1)")
		FilePrint(toopen$,"{")
			FilePrint(toopen$,"loopcomp!=1")
		FilePrint(toopen$,"}")
	FilePrint(toopen$,"}")
	If(setting[refresh]$=="Yes")
	{
		FilePrint(toopen$,"killthread(refresh_thread!)")
	}
	FilePrint(toopen$,"Run(cell[button_pressed!][link]$)")
	FilePrint(toopen$,"////////////////////////////////////////////////")
	FilePrint(toopen$,"///Created with EasyMenu Menu Creation System///")
	FilePrint(toopen$,"////////////////Program by Comfox///////////////")
	FilePrint(toopen$,"////////////////Finalis Software////////////////")
	FilePrint(toopen$,"////////////////////////////////////////////////")
	FilePrint(toopen$,"///////////////////////END//////////////////////")
	kill(stuff$)
	CloseFile(toopen$)
	kill(toopen$)
}

Method LoadMenu(toopen$)
{
	
	for(number! = 0; number! < number_of_cells!; number!++)
	{
		kill(cell[number!][x1]!)
		kill(cell[number!][x2]!)
		kill(cell[number!][y1]!)
		kill(cell[number!][y2]!)
		kill(cell[number!][textx]!)
		kill(cell[number!][texty]!)
		kill(cell[number!][layer]!)
		kill(cell[number!][text]$)
		kill(cell[number!][link]$)
		kill(cell[number!][image]$)
		kill(cell[number!][translucent]!)
		kill(cell[number!][tr]!)
		kill(cell[number!][tg]!)
		kill(cell[number!][tb]!)
		kill(cell[number!][width]!)
		kill(cell[number!][height]!)
		kill(cell[number!][display_text]$)
		kill(cell[number!][static_var_handle]$)
		kill(cell[number!][fontsize]!)
	}
	kill(number!)
	kill(number_of_cells!)
	kill(max_layer!)
	Clear()
	line!=1
	done_reading!=0
	OpenFileInput(toopen$,"Prg")
	data$=fileinput(toopen$)
	While(done_reading!==0)
	{
		data$=fileinput(toopen$)
		If(data$=="/////////////////////////////////")
		{
			done_reading!=1
		}
		Else
		{
			rpgcode(data$)
		}
	}
	CloseFile(toopen$)
	DrawAllCells()
}

Method VarSet(cellnum!,fontsize!,var$)
{
	cell[cellnum!][type]$="static_var"
	cell[cellnum!][static_var_handle]$=var$
	cell[cellnum!][fontsize]!=fontsize!
}

Method TextSet(cellnum!,fontsize!,text$)
{
	cell[cellnum!][type]$="text"
	cell[cellnum!][display_text]$=text$
	cell[cellnum!][fontsize]!=fontsize!
}


Method SetStringType(var1$,var2$)
{
	Switch(var2$)
	{
		case("literal") {
			varf$=var1$+"$"
		}
		case("numeric") {
			varf$=var1$+"!"
		}
	}
	returnmethod(varf$)
}


Method CheckCell(x!,y!)
{
	kill(numclicked!)
	kill(num!)
	numclicked!=0
	for(num! = 0; num! < number_of_cells!; num!++)
	{
		If(x! > cell[num!][x1]!)
		{
			If(x! < cell[num!][x2]!)
			{
				If(y! > cell[num!][y1]!)
				{
					If(y! < cell[num!][y2]!)
					{
						clicked[numclicked!]!=num!
						numclicked!=numclicked!+1
					}
				}
			}
		}
	}
	kill(num!)
	kill(x!)
	kill(y!)
}


Method Cycle()
{
	sel!=0
	If(numclicked! == 0)
	{
		sel!=0-1
	}
	If(numclicked! == 1)
	{
		sel!=clicked[0]!
	}
	If(numclicked! > 1)
	{
		doneloop!=0
		while(doneloop!=0)
		{
			DrawHighlighted(clicked[sel!]!)
			pressed$=Wait()
			Switch(pressed$)
			{
				case("UP") {
					sel!=sel!+1
				}
				case("DOWN") {
					sel!=sel!-1
				}
				case("RIGHT") {
					sel!=sel!+1
				}
				case("LEFT") {
					sel!=sel!-1
				}
				case("ENTER") {
					doneloop!=1
				}
			}
			If(sel! == numclicked!)
			{
				sel! = 0
			}
			If(sel! < 0)
			{
				sel! = numclicked!-1
			}
		}
		sel! = clicked[sel!]!
	}
	kill(doneloop!)
	for(moo! = 0; moo! < numclicked!; moo!++)
	{
		kill(clicked[moo!]!)
	}
	kill(numclicked!)
	kill(moo!)
}

Method DrawHighlighted(numbero!)
{
	DrawAllCells()
	colorrgb(hr!,hg!,hb!)
	DrawCell(numbero!)
	colorrgb(r!,g!,b!)
}











pixeltext(resx!/2.3,0,"EasyMenu 1.22")
pixeltext(resx!/2.3,getfontsize(),"Click for Menu")

while(end!==0)
{
	Getcolor(r!,g!,b!)
	MouseClick(moox!,mooy!)
	ActionMenu(moox!,mooy!,actionmenuwidth!,actionmenuheight!)
}




